#ifndef EDITPANEL_H
#define EDITPANEL_H

#include <list>
#include <wx/wx.h>
#include <vector>
#include "SmallClasses.h"

typedef vector< GeomObj*> ObjList;
typedef vector< pair<Coord, GeomObj*> > seznam2;
typedef vector< pair<Coord, pair <GeomObj*, GeomObj*> > > seznam3;
typedef vector< int> Sequence;
typedef vector<ObjList> UndoList;
//typedef list<pair<int, GeomObj*> > ListSelected;

enum toolType {tSELECT, tPOINT, tLINE, tCIRCLE, tCOMPASSES,
               tELLIPSE, tHYPERBOLE, tPARABOLA, tPERPENDICULAR, tPARALLEL, tSELECT_RECTANGLE,
               tEXTEND};

class EditPanel : public wxPanel
{
    wxWindow *parent;

public:
    EditPanel(wxWindow *parent,
            wxWindowID winid = wxID_ANY,
            const wxPoint& pos = wxDefaultPosition,
            const wxSize& size = wxDefaultSize,
            long style = wxTAB_TRAVERSAL | wxNO_BORDER,
            const wxString& name = wxPanelNameStr);

    void paintEvent(wxPaintEvent & evt);
    void OnEraseBackground(wxEraseEvent &evt);
    void Render(wxDC& dc);
    void OnMouseLeftClickUp(wxMouseEvent& evt);
    void OnMouseLeftClickDown(wxMouseEvent& evt);
    void OnMouseRightClickUp(wxMouseEvent& evt);
    void OnMouseRightClickDown(wxMouseEvent& evt);
    void OnMouseMove(wxMouseEvent& evt);
    void OnMouseWheel(wxMouseEvent& evt);
    void OnSize(wxSizeEvent& evt);
    void PaintGrid(wxDC& dc);
    double SnapX(double pX);
    double SnapY(double pY);
    void SelectPoint(double myX1, double myY1);
    void SelectPoints(Coord click, Coord click2);
    void SelectLine(double myX1, double myY1, int typ);
    void SelectLines(Coord click, Coord click2);
    void SelectCircle(double myX1, double myY1);
    void SelectCircles(Coord click, Coord click2);
    Coord Intersection(Coord line1A, Coord line2A, Coord line1B, Coord line2B);
    vector<Coord> IntersectionCircle(Coord A, Coord B, Coord S, double r);
    vector<Coord> IntersectionElipse(Coord A, Coord B, Coord S, double a, double b, double alfa);
    vector<Coord> IntersectionHyperbole(Coord A, Coord B, Coord S, double a, double b, double alfa);
    vector<Coord> IntersectionParabola(Coord A, Coord B, Coord S, double p, double alfa);
    wxString Save(wxString address);
    void Open();
    Coord SnapEndPoints(Coord coord);
    vector<Coord> IntersectionCircles(Coord S, double r1, Coord U, double r2);
    Coord SnapIntersect(Coord coord);
    void FindIntersectionLine(Coord pos, Coord pos2, GeomObj* line);
    void FindIntersectionCircle(Coord pos, double radius, GeomObj* circle);
    void SelectEllipses(Coord click, Coord click2);
    void SelectHyperboles(Coord click, Coord click2);
    void SelectParabolas(Coord click, Coord click2);


    ObjList CopyObjList();
    ObjList CopyObjList(ObjList &obj);
    void RefreshSnapPoints();
    void DeleteRList();

    seznam2 endPoints;
    seznam3 intersects;
    wxPaintDC dc;
    toolType tool;
    bool firstPoint;
    bool snapEndPoints;
    bool snapIntersect;
    bool snap;
    bool selectNow;
    GeomObj *selected;
    Sequence sequence;
    ObjList listSelected;
    ObjList objList;
    Coord mouseDownCoord;
    Coord oldCoord;
    Coord old2Coord;
    Coord coord;
    Coord mouseCoord;
    Coord mouseStart;
    Coord startMove;
    int gridSize;
    double zoom;
    double offsetx, offsety;
    double selectX, selectY;
    wxColour color, colorSelect;
    Name newName;
    UndoList undoList;
    UndoList rendoList;

    DECLARE_EVENT_TABLE()

};

#endif

